Plotting Examples
~~~~~~~~~~~~~~~~~~~~

pyrolite provides some functionality for basic plotting of geochemical data in the form
of spidergrams (pyrolite.plot.spider), ternary diagrams (pyrolite.plot.tern) and
density diagrams (i.e. 2D histograms, pyrolite.plot.density).
